@@ -110,7 +110,7 @@ GeomPathInteractive <- ggproto("GeomPath", Geom,
 			  munched$data_id <- as.character(munched$data_id)
 
 			if (!constant) {
-				interactiveSegmentsGrob(
+				interactive_segments_grob(
 						munched$x[!end], munched$y[!end], munched$x[!start], munched$y[!start],
 						tooltip = munched$tooltip[!end],
 						onclick = munched$onclick[!end],
@@ -128,7 +128,7 @@ GeomPathInteractive <- ggproto("GeomPath", Geom,
 				)
 			} else {
 				id <- match(munched$group, unique(munched$group))
-				interactivePolylineGrob(
+				interactive_polyline_grob(
 						munched$x, munched$y, id = id,
 						tooltip = munched$tooltip,
 						onclick = munched$onclick,
