@@ -17,8 +17,14 @@
 #' @param pointsize the default pointsize of plotted text in pixels, default to 12.
 #' @param width widget width
 #' @param height widget height
-#' @param hover_css css to apply when mouse is hover and element with a data-id attribute
-#' @param ... arguments passed on to \code{dsvg}
+#' @param tooltip_extra_css extra css (added to \code{position: absolute;pointer-events: none;})
+#' used to customize tooltip area.
+#' @param hover_css css to apply when mouse is hover and element with a data-id attribute.
+#' @param tooltip_opacity tooltip opacity
+#' @param tooltip_offx tooltip x offset
+#' @param tooltip_offy tooltip y offset
+#' @param zoom_max maximum zoom factor
+#' @param ... arguments passed on to \code{\link[rvg]{dsvg}}
 #' @seealso \code{\link{geom_path_interactive}},
 #' \code{\link{geom_point_interactive}},
 #' \code{\link{geom_polygon_interactive}},
@@ -29,7 +35,27 @@
 #' @example examples/geom_point_interactive.R
 #' @export
 ggiraph <- function(code,
-	pointsize = 12, width = 6, height = 6, hover_css = "{fill:orange;}", ...) {
+	pointsize = 12, width = 6, height = 6,
+	tooltip_extra_css,
+	hover_css,
+	tooltip_opacity = .9,
+	tooltip_offx = 10,
+	tooltip_offy = 0,
+	zoom_max = 6,
+	...) {
+
+  if( missing( tooltip_extra_css ))
+    tooltip_extra_css <- "padding:5px;background:black;color:white;border-radius:2px 2px 2px 2px;"
+  if( missing( hover_css ))
+    hover_css <- "fill:orange;"
+
+  stopifnot(is.numeric(tooltip_offx))
+  stopifnot(is.numeric(tooltip_offy))
+  stopifnot(is.numeric(tooltip_opacity))
+  stopifnot(tooltip_opacity > 0 && tooltip_opacity <= 1)
+  stopifnot(tooltip_opacity > 0 && tooltip_opacity <= 1)
+  stopifnot(is.numeric(zoom_max))
+  stopifnot( zoom_max > 1 )
 
 	ggiwid.options = getOption("ggiwid")
 	tmpdir = tempdir()
@@ -54,17 +80,29 @@ ggiraph <- function(code,
 
 	data_id_class <- basename(tempfile(tmpdir = "", fileext = "", pattern = "cl"))
 
+	if( grepl(x = tooltip_extra_css, pattern = "position[ ]*:") )
+	  stop("please, do not specify position in tooltip_extra_css, this parameter is managed by ggiraph.")
+	if( grepl(x = tooltip_extra_css, pattern = "pointer-events[ ]*:") )
+	  stop("please, do not specify pointer-events in tooltip_extra_css, this parameter is managed by ggiraph.")
+
 	x = list( html = HTML( svg_container ), code = js, canvas_id = ggiwid.options$svgid,
-	          data_id_class = data_id_class, hover_css = hover_css)
+	          data_id_class = data_id_class,
+	          tooltip_extra_css = tooltip_extra_css,
+	          hover_css = hover_css,
+	          tooltip_opacity = tooltip_opacity,
+	          tooltip_offx = tooltip_offx,
+	          tooltip_offy = tooltip_offy,
+	          zoom_max = zoom_max
+	          )
 
 	# create widget
 	htmlwidgets::createWidget(
 			name = 'ggiraph',
 			x,
-			width = width*72,
-			height = height*72,
+			width = NULL,
+			height = NULL,
 			package = 'ggiraph',
-			sizingPolicy = sizingPolicy(padding = 0, browser.fill = TRUE)
+			sizingPolicy = sizingPolicy(padding = 0, browser.fill = TRUE )
 	)
 }
 
@@ -72,14 +110,16 @@ ggiraph <- function(code,
 #' @description Render a ggiraph within an application page.
 #'
 #' @param outputId output variable to read the ggiraph from.
+#' @param width widget width
+#' @param height widget height
 #' @examples
 #' if( require(shiny) && interactive() ){
 #'   app_dir <- file.path( system.file(package = "ggiraph"), "shiny" )
 #'   shinyAppDir(appDir = app_dir )
 #' }
 #' @export
-ggiraphOutput <- function(outputId){
-	shinyWidgetOutput(outputId, 'ggiraph', package = 'ggiraph', width = "100%",height = "100%")
+ggiraphOutput <- function(outputId, width = "100%", height = "500px"){
+	shinyWidgetOutput(outputId, 'ggiraph', package = 'ggiraph', width = width, height = height)
 }
 
 #' @title Reactive version of ggiraph object
